@@ -244,6 +244,28 @@ impl<W> Sftp<W> {
         WriteEndWithCachedId::new(self, WriteEnd::new(self.shared_data.clone()))
     }
 
+    pub(super) fn auxiliary(&self) -> &Auxiliary {
+        self.shared_data.get_auxiliary()
+    }
+
+    /// Triggers the flushing of the internal buffer in `flush_task`.
+    ///
+    /// If there are pending requests, then flushing would happen immediately.
+    ///
+    /// If not, then the next time a request is queued in the write buffer, it
+    /// will be immediately flushed.
+    pub(super) fn trigger_flushing(&self) {
+        self.auxiliary().flush_immediately.notify_one();
+    }
+
+    /// Return number of pending requests in the write buffer.
+    pub(super) fn get_pending_requests(&self) -> u32 {
+        self.auxiliary().pending_requests.load(Ordering::Relaxed)
+    }
+}
+
+#[cfg(feature = "ci-tests")]
+impl<W> Sftp<W> {
     /// The maximum amount of bytes that can be written in one request.
     /// Writing more than that, then your write will be split into multiple requests
     ///
@@ -265,34 +287,6 @@ impl<W> Sftp<W> {
     pub fn max_buffered_write(&self) -> u32 {
         self.shared_data.get_auxiliary().max_buffered_write
     }
-
-    pub(super) fn auxiliary(&self) -> &Auxiliary {
-        self.shared_data.get_auxiliary()
-    }
-
-    /// Triggers the flushing of the internal buffer in `flush_task`.
-    ///
-    /// If there are pending requests, then flushing would happen immediately.
-    ///
-    /// If not, then the next time a request is queued in the write buffer, it
-    /// will be immediately flushed.
-    pub fn trigger_flushing(&self) {
-        self.auxiliary().flush_immediately.notify_one();
-    }
-
-    /// Return number of pending requests in the write buffer.
-    pub fn get_pending_requests(&self) -> u32 {
-        self.auxiliary().pending_requests.load(Ordering::Relaxed)
-    }
-
-    /// Return a cancellation token that will be cancelled if the `flush_task`
-    /// or `read_task` failed is called.
-    ///
-    /// Cancelling this returned token has no effect on any function in this
-    /// module.
-    pub fn get_cancellation_token(&self) -> CancellationToken {
-        self.auxiliary().cancel_token.child_token()
-    }
 }
 
 impl<W> Drop for Sftp<W> {
